/*---------------------------------------------------------------------------------------------------*\
|   PROGRAM NAME: 001-prod_master.sas                                                                 |
|                                                                                                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Version: Revised 1.0                                                                              |
|   Date: November 26, 2015                                                                           |
|                                                                                                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Program inputs:                                                                                   |
|       Common Components                                                                             |
|       Utility Code, Module Code, Lookup tables needed for producing the summary tables              |
|       MSCDM tables: DEMTABLE, ENRTABLE, DIATABLE, DISTABLE, PROCTABLE                               |
|                                                                                                     |
|   Program outputs:                                                                                  |
|      All of the temporary, intermediate, and final outputs to produce the summary tables            |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Contact:                                                                                          |
|       Mini-Sentinel Coordinating Center                                                             |
|       info@mini-sentinel.org                                                                        |
\*---------------------------------------------------------------------------------------------------*/

/*******************************************************************************************/
/***  DEV/QC PARMS SECTION - PLEASE BE SURE PARMS BELOW ARE SET CORRECTLY FOR PROD RUNS  ***/
/*******************************************************************************************/

%** Create extra output for QA/Debugging: { Y | N }  - REQUIRED;
%** Note: DEBUG should always be N for PROD;
%let DEBUG=N ;

%** Clean up WORK at start of each module: { Y | N }  - REQUIRED;
%** Note: CleanWORK should always be Y for PROD;
%let CleanWork=Y;

%** Clean up DPTemp files as soon as no longer needed: { Y | N }  - REQUIRED;
%** Note: CleanDPTemp should always be Y for PROD;
%let CleanDPTemp=Y;

%** Create separate logs for each module: ( Y | N) - REQUIRED;
%** Note: ModuleLogs should always be Y for PROD;
%let ModuleLogs=Y;

%** Text Files parm - REQUIRED;
%** Indicates whether text files are to be generated and their type:;
%**  N = No, do not generate text files;
%**  C = Comma delimited;
%**  P = Pipe delimited;
%**  T = Tab delimited;
%** Note: TextFiles should always be set to T for PROD;
%let TextFiles=T;

/*************************************************************************************/
/*** SETUP FOR MODULES RUN  -- PLEASE DONT CHANGE                                  ***/
/*************************************************************************************/

/* Define path used to include modules */
%let MODULE_CODE = &INFOLDER.module_code/ ;
%let MODULE_CODE = %ms_clean_path(&MODULE_CODE) ;

/* Run STARTUP code */;
%inc "&MODULE_CODE.000-startup.sas" /source;

/*********************************************************************************************/
/*** RUN SUMMARY TABLE MODULES  -- PLEASE DONT CHANGE                                      ***/
/*********************************************************************************************/

/* When not running all modules use instead "900-adhoc_master" */

%INC_NEXT( code=AGE_GROUPS );
%INC_NEXT( code=DEM_ETL ) ;

%INC_NEXT( code=ENR_ETL ) ;
%INC_NEXT( code=PREV_PAT_KEYS ) ;
%INC_NEXT( code=ENROLLMENT , DeleteDPT=Enr_Spans:) ;

%INC_NEXT( code=DX_ETL ) ;
%INC_NEXT( code=DX_CODE_FILES ) ;
%INC_NEXT( code=DX3_PREV ) ;
%INC_NEXT( code=DX3_INCIDENT_EPISODES ) ;
%INC_NEXT( code=INCIDENT_DX3 , DeleteDPT=DX3: DX_3: ) ;
%INC_NEXT( code=DX4_PREV , DeleteDPT=DX4: DX_4: ) ;
%INC_NEXT( code=DX5_PREV , DeleteDPT=DX: ) ;

%INC_NEXT( code=PX_ETL ) ;
%INC_NEXT( code=PX_CODE_FILES ) ;
%INC_NEXT( code=PX_HCPCS_PREV , DeleteDPT=HC_CPT: ) ;
%INC_NEXT( code=PX_ICD9_3D_PREV , DeleteDPT=PX_ICD3: ) ;
%INC_NEXT( code=PX_ICD9_4D_PREV , DeleteDPT=PX: ) ;

%INC_NEXT( code=RX_LOOKUP_KEYS ) ;
%INC_NEXT( code=RX_ETL ) ;
%INC_NEXT( code=RX_ATTACH_KEYS ) ;

%INC_NEXT( code=RX_DRUG_CLASS ) ;
%INC_NEXT( code=RX_DRUG_CLASS_INCIDENT_EPISODES ) ;
%INC_NEXT( code=INCIDENT_DRUG_CLASS , DeleteDPT=RX_DrugClass: RxDrugClass: );

%INC_NEXT( code=RX_GENERIC_NAME ) ;
%INC_NEXT( code=RX_GENERIC_NAME_INCIDENT_EPISODES ) ;
%INC_NEXT( code=INCIDENT_GENERIC_NAME , DeleteDPT=RX: );

%INC_NEXT( code=EXPORT , clean_work_a=&CleanWork, DeleteDPT=KillAll ) ;

/*********************************************************************************************/
/*** RUN SHUTDOWN CODE  -- PLEASE DONT CHANGE                                              ***/
/*********************************************************************************************/
%inc "&MODULE_CODE.999-shutdown.sas" /source;


* End of 001-prod_master.sas;