/*---------------------------------------------------------------------------------------------------*\
|   PROGRAM NAME: px_code_files.sas                                                                   |
|                                                                                                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Version: Revised 1.0                                                                              |
|   Date: September 22, 2015                                                                          |
|   MOD 10/20/15: Enabled carrying of the SORTEDBY= attribute to output datasets                      |
|   MOD 12/08/15: Use a single DS view as input instead of multiple time-split DS                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Program inputs:                                                                                   |
|      Procedure records processed by PX_ETL                                                          |
|   Program outputs:                                                                                  |
|       Multiple HCPCS/CPT temporary tables split by time segment                                     |
|       Multiple Px_ICD9_3d temporary tables split by time segment                                    |
|       Multiple Px_ICD9_4d temporary tables split by time segment                                    |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Contact:                                                                                          |
|       Mini-Sentinel Coordinating Center                                                             |
|       info@mini-sentinel.org                                                                        |
\*---------------------------------------------------------------------------------------------------*/

*** Create three new temporary tables as follows:
*** 1 HC_CPT:      PXCode_Type is one of "C4" or "HC.
*** 2 Px_ICD9_3d:  PXCode_Type="09" and extract only the left-most 3 characters of Px
*** 3 Px_ICD9_4d:  PXCode_Type="09" and extract only the left-most 4 characters of Px, but only when the 4th and 5th characters are both not blank;
*** The counts for the rows in two of the tables should have this relationship: Px_ICD9_3d >= Px_ICD9_4d;

%macro Px_code_files_years;
  %*** Set local macro variables;
  %local Year SortedByPx;
  %*** Get SORTEDBY attribute for all output datasets;
  %let SortedByPx=%retrieve_sortedby(dsname=DPTemp.PXV,FullExpr=N);
  %put &=SortedByPx;

  %*** Check that SORTEDBY variables are in the list of kept variables;
  %* Set list of variables to be kept in all PX files;
  %let pxKeep=AgeTimePeriodGroupKey Code PatKey Period Px_CodeType Setting Sex;
  %* Filter SortedBy vars for px;
  %SortedBy_check(
    SourceWrds=&SortedbyPx.,
    ReturnVar=SortedByPx,
    CheckWrds=&pxKeep.
  );
  %** If there are SortedBy variables, then create full data set option expression;
  %if %length(&SortedByPx.)>0 %then %let SortedByPx=%str(SortedBy=&SortedByPx.);

  data
    %do Year=&DP_StartYear. %to &DP_EndYear.;
      DPTemp.HC_CPT&Year.    (Keep=&pxKeep. &SortedByPx.)
      DPTemp.Px_ICD9_3d&Year.(Keep=&pxKeep. &SortedByPx.)
      DPTemp.Px_ICD9_4d&Year.(Keep=&pxKeep. &SortedByPx.)
    %end;
    ;
    set DPTemp.PxV(rename=(Code=_Code));
    %do Year=&DP_StartYear. %to &DP_EndYear.;
      if Period eq "&Year." then do;
        if Px_Codetype in ("C4" "HC") then do;
          ** HCPCS and CPT4;
          Code=_Code;
          output DPTemp.HC_CPT&Year.;
          return; /* got everything we need for this obs, return to top of data step */
        end;
        else if Px_Codetype = "09" then do;
          ** 3-digit ICD-9 procedure code;
          Code=substr(_Code,1,3);
          output DPTemp.Px_ICD9_3d&Year.;
          ** 4-digit ICD-9 procedure code;
          if substr(_Code,4,1) NE " " then do;
            Code=substr(_Code,1,4);
            output DPTemp.Px_ICD9_4d&Year.;
          end;
          return; /* got everything we need for this obs, return to top of data step */
        end;
      end;
    %end;
    drop _: ;
  run;

  %*** QC on counts of files;
  %if &DEBUG.=Y %then %do;
  *** DEBUGGING: Check counts of 2 datasets;
    %do Year=&DP_StartYear. %to &DP_EndYear.;
      %put Counts of 2 &Year. Px files are: Px_ICD9_3d&Year. = %dsn_obs(dsn=DPTemp.Px_ICD9_3d&Year.) >= Px_ICD9_4d&Year. = %dsn_obs(dsn=DPTemp.Px_ICD9_4d&Year.);
    %end;
  %end;
%mend;
%Px_code_files_years;

* End of px_code_files.sas;
